@@ -28,6 +28,7 @@
 #include "pk-cmd.h"
 #include "pk-table.h"
 #include "pk-hserver.h"
+#include "pk-repl.h" /* For poke_completion_function */
 
 struct pk_info_payload
 {
@@ -120,6 +121,7 @@ print_type_decl (int kind,
 
   pk_table_row (table);
 
+#if HAVE_HSERVER
   /* Emit an hyperlink to execute `.info type NAME'.  */
   {
     char *cmd;
@@ -132,6 +134,9 @@ print_type_decl (int kind,
     pk_table_column_hl (table, name, hyperlink);
     free (hyperlink);
   }
+#else
+  pk_table_column (table, name);
+#endif
 
   if (source)
     asprintf (&source_str, "%s:%d",
@@ -146,7 +151,7 @@ print_type_decl (int kind,
 #define PREP_REGEXP_PAYLOAD                                             \
   do                                                                    \
     {                                                                   \
-      if (PK_CMD_ARG_STR (argv[1]) != '\0')                             \
+      if (PK_CMD_ARG_STR (argv[1]) != NULL)                             \
         {                                                               \
           if (regcomp (&regexp,                                         \
                        PK_CMD_ARG_STR (argv[1]),                        \
@@ -260,10 +265,11 @@ pk_cmd_info_type (int argc, struct pk_cmd_arg argv[], uint64_t uflags)
      pass the resulting Pk_Type to pk_info_type.  */
   {
     char *stmt = NULL;
+    pk_val exit_exception = PK_NULL;
 
     asprintf (&stmt, "pk_info_type (typeof (%s));", name);
     if (pk_compile_statement (poke_compiler, stmt, NULL, NULL,
-                              NULL) != PK_OK)
+                              &exit_exception) != PK_OK)
       {
         pk_puts ("internal error: executing pk_info_type in pk_cmd_info_type."
                  "  Please report this.\n");
@@ -271,6 +277,9 @@ pk_cmd_info_type (int argc, struct pk_cmd_arg argv[], uint64_t uflags)
         return 0;
       }
     free (stmt);
+
+    if (exit_exception != PK_NULL)
+      poke_handle_exception (exit_exception);
   }
 
   return 1;
@@ -287,19 +296,18 @@ pk_cmd_info_type (int argc, struct pk_cmd_arg argv[], uint64_t uflags)
   return 0;
 }
 
-
 const struct pk_cmd info_var_cmd =
-  {"variables", "s?", "", 0, NULL, pk_cmd_info_var,
-   "info variables [REGEXP]", NULL};
+  {"variables", "s?", "", 0, NULL, NULL, pk_cmd_info_var,
+   "info variables [REGEXP]", poke_completion_function};
 
 const struct pk_cmd info_fun_cmd =
-  {"functions", "s?", "", 0, NULL, pk_cmd_info_fun,
-   "info functions [REGEXP]", NULL};
+  {"functions", "s?", "", 0, NULL, NULL, pk_cmd_info_fun,
+   "info functions [REGEXP]", poke_completion_function};
 
 const struct pk_cmd info_types_cmd =
-  {"types", "s?", "", 0, NULL, pk_cmd_info_types,
-   "info types [REGEXP]", NULL};
+  {"types", "s?", "", 0, NULL, NULL, pk_cmd_info_types,
+   "info types [REGEXP]", poke_completion_function};
 
 const struct pk_cmd info_type_cmd =
-  {"type", "s", "", 0, NULL, pk_cmd_info_type,
-   "info type NAME", NULL};
+  {"type", "s", "", 0, NULL, NULL, pk_cmd_info_type,
+   "info type NAME", poke_completion_function};
